This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). Upgrades from major to major versions, such a change from version `5.6.0` to `6.0.0`, might require local configuration updates to ensure compatibility with your current scripts. Make sure you have the latest version of the SDK using `pip install -U cortex-client`.
## [1.2.0] - 2020-06-24
### Added
* Bump cortex-python to 1.4.0 to enable new cortex client apis, supporting ssl_verify

## [1.1.0] - 2019-09-12
### Added
* Support for user specified base directory in local mode.

## [1.0.3] - 2019-08-21
### Modified
* Changes to Dockerfile templates for actions.
### Removed
* Managed Projects builder service.

## [1.0.2] - 2019-08-15
### Modified
* Changes to Makefile in preparation for CI/CD.

## [1.0.0] - 2019-07-12
### Added
* First port/extract from the deprecated cortex-client module.
